<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

/**
 * Upgrade newsletter module to version 3.0.1
 *
 * @author CIEXT skeleton
 */
class Newsletter_upgrade_1_1_0 extends Abstract_upgrade
{

    public function up()
    {
        $ci = & get_instance();
        $ci->load->library('emailmng/emailmng_installer');
        $ci->emailmng_installer
                ->set_subject($ci->lang->line('New user subscribed to the newsletter'))
                ->set_message($ci->lang->line('New user [[email]] subscribed to the newsletter'), $ci->lang->line('[[email]] - user email'))
                ->add_template('newsletter_new_user_subscribed');

        return '3.0.1';
    }

    public function down()
    {
        return '1.1.0';
    }

}
