<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

/**
 * Upgrade Newsletter module to version 3.6.0
 *
 * @author CIEXT skeleton
 */
class Newsletter_upgrade_3_1_0 extends Abstract_upgrade
{

    public function up()
    {
        if (!$this->is_column_exist('newsletter_email', 'tags')) {
            get_instance()->db->query('ALTER TABLE `newsletter_email` ADD `tags` varchar(255) CHARACTER SET utf8;');
        }

        return '3.6.0';
    }

    public function down()
    {
        return '3.1.0';
    }

}
